pub fn load_sessions_by_key(keys: &[SessionKey]) -> Result<Vec<Session>>Expand description
Load only the requested resumable sessions from their owning agent stores.
Errors
Returns an error when a matching supported session cannot be read or parsed.